@@ -3,7 +3,7 @@
 set -eu -o pipefail
 
 SCRIPT_DIR="$( cd "$( dirname "${BASH_SOURCE[0]}" )" >/dev/null && pwd )"
-cd $SCRIPT_DIR/..
+cd "$SCRIPT_DIR/.."
 
 version=${1:-}
 if [[ -z "$version" ]]; then
@@ -19,8 +19,9 @@ fi
 sed -i -e "0,/version =/ s!^version = \".*\"!version = \"${version}\"!" Cargo.toml
 git add Cargo.toml
 cargo build --release
+nix flake check -L
 git add Cargo.lock
 git commit -m "bump version to ${version}"
 git tag "${version}"
 
-echo 'now run `git push --tags origin master`'
+echo "now run 'git push --tags origin master'"
