@@ -9,31 +9,31 @@ pub fn ioctl_read(fd: RawFd, cmd: c_ulong, data: &mut [u8]) -> Result<()> {
     Errno::result(res).map(drop)
 }
 
-#[cfg(any(target_env = "musl"))]
+#[cfg(target_env = "musl")]
 pub fn ioctl_read(fd: RawFd, cmd: c_ulong, data: &mut [u8]) -> Result<()> {
     let res = unsafe { libc::ioctl(fd, cmd as i32, data) };
     Errno::result(res).map(drop)
 }
 
-#[cfg(not(any(target_env = "musl")))]
+#[cfg(not(target_env = "musl"))]
 pub fn ioctl_write(fd: RawFd, cmd: c_ulong, data: &[u8]) -> Result<()> {
     let res = unsafe { libc::ioctl(fd, cmd, data) };
     Errno::result(res).map(drop)
 }
 
-#[cfg(any(target_env = "musl"))]
+#[cfg(target_env = "musl")]
 pub fn ioctl_write(fd: RawFd, cmd: c_ulong, data: &[u8]) -> Result<()> {
     let res = unsafe { libc::ioctl(fd, cmd as i32, data) };
     Errno::result(res).map(drop)
 }
 
-#[cfg(not(any(target_env = "musl")))]
+#[cfg(not(target_env = "musl"))]
 pub fn ioctl(fd: RawFd, cmd: c_ulong) -> Result<()> {
     let res = unsafe { libc::ioctl(fd, cmd) };
     Errno::result(res).map(drop)
 }
 
-#[cfg(any(target_env = "musl"))]
+#[cfg(target_env = "musl")]
 pub fn ioctl(fd: RawFd, cmd: c_ulong) -> Result<()> {
     let res = unsafe { libc::ioctl(fd, cmd as i32) };
     Errno::result(res).map(drop)
